"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
class NodeManager {
    /**
     * Represents a nodeManager instance that will be controlled via REST
     * @param {string} nodeManagerUrl - The HTTP URL and port to the nodeManager instance
     */
    constructor(nodeManagerUrl) {
        this.nodeManagerUrl = nodeManagerUrl;
    }
    /**
     * Can be used to check if a specified address contains an Ethereum contract
     * @param {string} contractAddress - contract address on the blockchain
     * @returns A Promise with a boolean that is true if the contract exists
     */
    checkIfContractExists(contractAddress) {
        return __awaiter(this, void 0, void 0, function* () {
            let result = yield axios_1.default.get(this.nodeManagerUrl + "/checkIfContractExists/" + contractAddress);
            return result.data;
        });
    }
    /**
     * Can be used to call a Smart Contract function.
     * This function expects a Web3.Transaction object as the parameter
     * @param {Transaction} tx - Transaction Object
     * @returns a promise with the predicted transaction hash
     */
    callFunction(tx) {
        return __awaiter(this, void 0, void 0, function* () {
            let response = yield axios_1.default.post(this.nodeManagerUrl + "/callFunction", tx);
            return response.data;
        });
    }
    /**
     * Can be used to send a transaction
     * This function expects a Web3.Transaction object as the parameter
     * @param {Transaction} tx - Transaction Object
     * @returns a promise with the predicted transaction hash
     */
    sendTx(tx) {
        return __awaiter(this, void 0, void 0, function* () {
            let response = yield axios_1.default.post(this.nodeManagerUrl + "/sendTx", tx);
            return response.data;
        });
    }
    /**
     * Can be used to wait for a transaction
     * The function uses long polling and the promise will resolve once the transaction is mined
     * @param {string} tx - transaction address
     * @returns a Promise with the TransactionReceipt object that resolves once the transaction is mined.
     */
    waitForTx(tx) {
        return __awaiter(this, void 0, void 0, function* () {
            let response = yield axios_1.default.get(this.nodeManagerUrl + '/waitForTx/' + tx);
            return response.data;
        });
    }
    /**
     * Can be used to get the address of the account that is configured in the bc node manager instance
     * @returns a promise with the account address as a string
     */
    getAccountAddress() {
        return __awaiter(this, void 0, void 0, function* () {
            let response = yield axios_1.default.get(this.nodeManagerUrl + '/getAccountAddress');
            return response.data;
        });
    }
}
exports.default = NodeManager;
//# sourceMappingURL=library.js.map